==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PlatformPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PlatformConditionEvaluatorPlatform;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PlatformPolicyRuleCondition
 */
@JsonPropertyOrder({ PlatformPolicyRuleCondition.JSON_PROPERTY_EXCLUDE,
        PlatformPolicyRuleCondition.JSON_PROPERTY_INCLUDE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PlatformPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EXCLUDE = "exclude";
    private List<PlatformConditionEvaluatorPlatform> exclude = null;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private List<PlatformConditionEvaluatorPlatform> include = null;

    public PlatformPolicyRuleCondition() {
    }

    public PlatformPolicyRuleCondition exclude(List<PlatformConditionEvaluatorPlatform> exclude) {

        this.exclude = exclude;
        return this;
    }

    public PlatformPolicyRuleCondition addexcludeItem(PlatformConditionEvaluatorPlatform excludeItem) {
        if (this.exclude == null) {
            this.exclude = new ArrayList<>();
        }
        this.exclude.add(excludeItem);
        return this;
    }

    /**
     * Get exclude
     *
     * @return exclude
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<PlatformConditionEvaluatorPlatform> getExclude() {
        return exclude;
    }

    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExclude(List<PlatformConditionEvaluatorPlatform> exclude) {
        this.exclude = exclude;
    }

    public PlatformPolicyRuleCondition include(List<PlatformConditionEvaluatorPlatform> include) {

        this.include = include;
        return this;
    }

    public PlatformPolicyRuleCondition addincludeItem(PlatformConditionEvaluatorPlatform includeItem) {
        if (this.include == null) {
            this.include = new ArrayList<>();
        }
        this.include.add(includeItem);
        return this;
    }

    /**
     * Get include
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<PlatformConditionEvaluatorPlatform> getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(List<PlatformConditionEvaluatorPlatform> include) {
        this.include = include;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PlatformPolicyRuleCondition platformPolicyRuleCondition = (PlatformPolicyRuleCondition) o;
        return Objects.equals(this.exclude, platformPolicyRuleCondition.exclude)
                && Objects.equals(this.include, platformPolicyRuleCondition.include);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(exclude, include);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PlatformPolicyRuleCondition {\n");
        sb.append("    exclude: ").append(toIndentedString(exclude)).append("\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/PlatformPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PlatformConditionEvaluatorPlatform;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PlatformPolicyRuleCondition
 */
@JsonPropertyOrder({ PlatformPolicyRuleCondition.JSON_PROPERTY_EXCLUDE,
        PlatformPolicyRuleCondition.JSON_PROPERTY_INCLUDE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PlatformPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EXCLUDE = "exclude";
    private List<PlatformConditionEvaluatorPlatform> exclude = null;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private List<PlatformConditionEvaluatorPlatform> include = null;

    public PlatformPolicyRuleCondition() {
    }

    public PlatformPolicyRuleCondition exclude(List<PlatformConditionEvaluatorPlatform> exclude) {

        this.exclude = exclude;
        return this;
    }

    public PlatformPolicyRuleCondition addexcludeItem(PlatformConditionEvaluatorPlatform excludeItem) {
        if (this.exclude == null) {
            this.exclude = new ArrayList<>();
        }
        this.exclude.add(excludeItem);
        return this;
    }

    /**
     * Get exclude
     *
     * @return exclude
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<PlatformConditionEvaluatorPlatform> getExclude() {
        return exclude;
    }

    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExclude(List<PlatformConditionEvaluatorPlatform> exclude) {
        this.exclude = exclude;
    }

    public PlatformPolicyRuleCondition include(List<PlatformConditionEvaluatorPlatform> include) {

        this.include = include;
        return this;
    }

    public PlatformPolicyRuleCondition addincludeItem(PlatformConditionEvaluatorPlatform includeItem) {
        if (this.include == null) {
            this.include = new ArrayList<>();
        }
        this.include.add(includeItem);
        return this;
    }

    /**
     * Get include
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<PlatformConditionEvaluatorPlatform> getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(List<PlatformConditionEvaluatorPlatform> include) {
        this.include = include;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PlatformPolicyRuleCondition platformPolicyRuleCondition = (PlatformPolicyRuleCondition) o;
        return Objects.equals(this.exclude, platformPolicyRuleCondition.exclude)
                && Objects.equals(this.include, platformPolicyRuleCondition.include);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(exclude, include);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PlatformPolicyRuleCondition {\n");
        sb.append("    exclude: ").append(toIndentedString(exclude)).append("\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
